@@ -1,3 +1,4 @@
+use nxui::graphic::icon::Icon;
 use nxui::natives_and_messaging::{AWS_UTILITY, WS_NORMAL};
 use nxui::window::{AdvancedOptions, Application, Attributes, Frame};
 
@@ -21,7 +22,15 @@ impl Application for UtilityApplication {
     }
 
     fn attributes(&self) -> Attributes {
-        Attributes::new(WS_NORMAL, "Utility Window".to_string(), 400, 675, 100, 100)
+        Attributes::new(
+            WS_NORMAL,
+            "Utility Window".to_string(),
+            "io.github.lattesyobon.utility".to_string(),
+            400,
+            675,
+            100,
+            100,
+        )
     }
 
     fn is_child_window(&self) -> bool {
@@ -29,10 +38,10 @@ impl Application for UtilityApplication {
     }
 
     fn advanced_options(&self) -> AdvancedOptions {
-        AdvancedOptions::new(AWS_UTILITY)
+        AdvancedOptions::new(AWS_UTILITY, Icon::default().get_icon())
     }
 
-    fn ui(&self, frame: Frame) {
+    fn ui(&self, frame: &Frame) {
         frame.show();
     }
 }
