@@ -1,8 +1,11 @@
 use nxui::messagebox::MessageBox;
 use nxui::natives_and_messaging::WS_NORMAL;
+use nxui::widget::combobox::ComboBox;
+use nxui::widget::listbox::ListBox;
 use nxui::widget::menu::Menu;
 use nxui::widget::menubar::MenuBar;
 use nxui::widget::menuitem::MenuItem;
+use nxui::widget::textedit::TextEdit;
 use nxui::window::{Application, Attributes, Frame};
 
 fn main() {
@@ -45,7 +48,6 @@ impl Application for WidgetWindow {
         use nxui::widget::checkbox::CheckBox;
         use nxui::widget::label::Label;
         use nxui::widget::radiobutton::RadioButton;
-        use nxui::widget::textedit::TextEdit;
         Label::new(
             Attributes::new(
                 WS_NORMAL,
@@ -113,6 +115,19 @@ impl Application for WidgetWindow {
             frame,
         )
         .show();
+        Label::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Combo Box".to_string(),
+                "".to_string(),
+                350,
+                50,
+                650,
+                400,
+            ),
+            frame,
+        )
+        .show();
         TextEdit::new(
             Attributes::new(
                 WS_NORMAL,
@@ -126,6 +141,45 @@ impl Application for WidgetWindow {
             frame,
         )
         .show();
+        ComboBox::new(
+            Attributes::new(
+                WS_NORMAL,
+                "Rich Text Edit".to_string(),
+                "".to_string(),
+                550,
+                45,
+                650,
+                450,
+            ),
+            frame,
+        )
+        .show();
+        Label::new(
+            Attributes::new(
+                WS_NORMAL,
+                "List Box".to_string(),
+                "".to_string(),
+                350,
+                50,
+                650,
+                510,
+            ),
+            frame,
+        )
+        .show();
+        ListBox::new(
+            Attributes::new(
+                WS_NORMAL,
+                "List Box".to_string(),
+                "".to_string(),
+                350,
+                115,
+                650,
+                540,
+            ),
+            frame,
+        )
+        .show();
 
         // Initialize Menu
         let menu = initialize_menu();
