@@ -1,22 +1,28 @@
+//! Sample dialog window
+
 use crate::natives_and_messaging::WS_NORMAL;
-use crate::window::{Attributes, Frame};
 use crate::window::dialog::Dialog;
+use crate::window::{Attributes, Frame};
 
-pub struct DemoDialog {
-
-}
+pub struct DemoDialog {}
 
 impl DemoDialog {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
 }
 
 impl Dialog for DemoDialog {
     fn attributes(&self) -> Attributes {
-        Attributes::new(WS_NORMAL, "Demo Dialog".to_string(), "io.github.lattesyobon.demo".to_string(),320, 250, 50, 50)
+        Attributes::new(
+            WS_NORMAL,
+            "Demo Dialog".to_string(),
+            "io.github.lattesyobon.demo".to_string(),
+            320,
+            250,
+            50,
+            50,
+        )
     }
 
     fn frame(&self) -> Frame {
@@ -26,4 +32,4 @@ impl Dialog for DemoDialog {
     fn ui(&self, frame: Frame) {
         frame.show();
     }
-}
\ No newline at end of file
+}
