@@ -1,36 +1,39 @@
+//! Dialog to select a directory.
+
 use std::ptr::null_mut;
 
 #[cfg(windows)]
 pub struct DirectoryChooser<'a> {
-    pub title: &'a str
+    pub title: &'a str,
 }
 
 #[cfg(windows)]
 impl<'a> DirectoryChooser<'a> {
     pub fn new(title: &'a str) -> Self {
-        Self {
-            title
-        }
+        Self { title }
     }
 
     pub fn show(&self) -> String {
         unsafe {
+            use crate::util::pwstr_to_string;
             use winapi::shared::winerror::SUCCEEDED;
-            use winapi::um::combaseapi::{CoCreateInstance, CoInitializeEx, CoUninitialize, CLSCTX_ALL};
+            use winapi::um::combaseapi::{
+                CoCreateInstance, CoInitializeEx, CoUninitialize, CLSCTX_ALL,
+            };
             use winapi::um::objbase::{COINIT_APARTMENTTHREADED, COINIT_DISABLE_OLE1DDE};
             use winapi::um::shobjidl::*;
             use winapi::um::shobjidl_core::{IShellItem, SIGDN_FILESYSPATH};
-            use winapi::Interface;
             use winapi::um::winnt::PWSTR;
-            use crate::util::pwstr_to_string;
+            use winapi::Interface;
 
             #[allow(non_upper_case_globals)]
-            const CLSID_FileOpenDialog: winapi::shared::guiddef::GUID = winapi::shared::guiddef::GUID {
-                Data1: 0xdc1c5a9c,
-                Data2: 0xe88a,
-                Data3: 0x4dde,
-                Data4: [0xa5, 0xa1, 0x60, 0xf8, 0x2a, 0x20, 0xae, 0xf7],
-            };
+            const CLSID_FileOpenDialog: winapi::shared::guiddef::GUID =
+                winapi::shared::guiddef::GUID {
+                    Data1: 0xdc1c5a9c,
+                    Data2: 0xe88a,
+                    Data3: 0x4dde,
+                    Data4: [0xa5, 0xa1, 0x60, 0xf8, 0x2a, 0x20, 0xae, 0xf7],
+                };
             let mut sel_dir: String = "".to_string();
 
             let mut hr = CoInitializeEx(
@@ -79,22 +82,22 @@ impl<'a> DirectoryChooser<'a> {
 
 #[cfg(unix)]
 pub struct DirectoryChooser<'a> {
-    pub title: &'a str
+    pub title: &'a str,
 }
 
 #[cfg(unix)]
 impl<'a> DirectoryChooser<'a> {
     pub fn new(title: &'a str) -> Self {
-        Self {
-            title
-        }
+        Self { title }
     }
 
     pub fn show(&self) -> String {
         use gtk::prelude::{DialogExt, WidgetExt, WidgetExtManual};
-        let dialog = gtk::FileChooserDialog::new::<gtk::Window>(Some(self.title),
-                                                                None,
-                                                                gtk::FileChooserAction::SelectFolder);
+        let dialog = gtk::FileChooserDialog::new::<gtk::Window>(
+            Some(self.title),
+            None,
+            gtk::FileChooserAction::SelectFolder,
+        );
 
         dialog.add_button("Cancel", gtk::ResponseType::Cancel.into());
         dialog.add_button("Open", gtk::ResponseType::Accept.into());
@@ -109,8 +112,10 @@ impl<'a> DirectoryChooser<'a> {
             dir = "".to_string()
         }
 
-        unsafe { dialog.destroy(); }
+        unsafe {
+            dialog.destroy();
+        }
 
         dir
     }
-}
\ No newline at end of file
+}
