@@ -120,8 +120,12 @@ pub const WS_NOCAPTION: gtk::WindowType = gtk::WindowType::Popup;
 #[cfg(windows)]
 pub const AWS_UTILITY: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE =
     windows_sys::Win32::UI::WindowsAndMessaging::WS_EX_TOOLWINDOW;
+#[cfg(windows)]
+pub const AWS_NONE: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE = 0;
 #[cfg(unix)]
 pub const AWS_UTILITY: gtk::gdk::WindowTypeHint = gtk::gdk::WindowTypeHint::Utility;
+#[cfg(unix)]
+pub const AWS_NONE: gtk::gdk::WindowTypeHint = gtk::gdk::WindowTypeHint::Normal;
 
 /// File Chooser Attributes
 #[cfg(windows)]
