@@ -12,6 +12,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
     // Get attributes
     let attributes = application.attributes();
     let storage = Storage::new(get_app_dirs(app_name));
+    let advanced_option = application.advanced_options();
     // startup process
     if application.is_child_window() == false {
         storage.create_app_dir();
@@ -62,7 +63,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
         let atom = RegisterClassA(&wc);
         debug_assert!(atom != 0);
         let win = CreateWindowExA(
-            application.advanced_options().get_style(),
+            advanced_option.get_style(),
             "window".as_ptr(),
             format!("{}\0", attributes.title).as_ptr(),
             attributes.style | WS_VISIBLE,
