@@ -2,11 +2,13 @@
 
 pub mod button;
 pub mod checkbox;
+pub mod combobox;
+pub mod hbox;
 pub mod label;
+pub mod listbox;
 pub mod menu;
 pub mod menubar;
 pub mod menuitem;
 pub mod radiobutton;
 pub mod textedit;
 pub mod vbox;
-pub mod hbox;
