@@ -1,5 +1,6 @@
 //! Provides traits and tools for displaying windows.
 
+use crate::graphic::icon::Icon;
 use crate::io::storage::Storage;
 use crate::widget::menubar::MenuBar;
 
@@ -110,6 +111,20 @@ impl Frame {
             SetMenu(self.handle, menu.get_menu());
         }
     }
+
+    pub fn set_icon(&self, icon: Icon) {
+        use windows_sys::Win32::Foundation::WPARAM;
+        use windows_sys::Win32::UI::WindowsAndMessaging::*;
+        unsafe {
+            SendMessageA(self.handle, WM_SETICON, ICON_BIG as WPARAM, icon.get_icon());
+            SendMessageA(
+                self.handle,
+                WM_SETICON,
+                ICON_SMALL as WPARAM,
+                icon.get_icon(),
+            );
+        }
+    }
 }
 
 #[cfg(windows)]
@@ -283,6 +298,13 @@ impl Frame {
         use gtk::prelude::*;
         self.application.set_menubar(Some(&menu.get_menu()));
     }
+
+    pub fn set_icon(&self, icon: Icon) {
+        use gtk::prelude::*;
+        use std::path::Path;
+        self.handle
+            .set_icon_from_file(&Path::new(icon.get_file_name().as_str()));
+    }
 }
 
 #[cfg(unix)]
